/**
 * Copyright (c) 2005-2012 EBM WebSourcing, 2012-2017 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.microkernel.communication.jndi.agent.msg.request;

import java.io.Serializable;

/**
 * This class is a registry request which is used to send request to the registry.
 * @author ddesjardins - EBM WebSourcing
 */
public class RegistryRequest implements Serializable {

    /**
     * Serial UID
     */
    private static final long serialVersionUID = -5602207623986086268L;

    /**
     * Flag indicating that it is a local connection
     */
    private boolean localConnection;

    /**
     * Request types
     */
    public static enum RequestType {
        /**
         *
         */
        addToEnvironment,
        /**
         * BIND : arg1 = context name, arg2 = key, arg3 = value
         */
        bind,
        /**
         * CREATE SUBCONTEXT : arg1 = context name, arg2 = name of the context
         * to create
         */
        createSubcontext,
        /**
         * DESTROY SUBCONTEXT : arg1 = context name, arg2 = nam of the context
         * to destroy
         */
        destroySubcontext,
        /**
         * LIST : arg1 = context name, arg2 = context name to list the content
         */
        list,
        /**
         * LIST BINDINGS : arg1 = context name, arg2 = context name to list the
         * content
         */
        listBindings,
        /**
         * LOOKUP : arg1 = context name, arg2 = key
         */
        lookup,
        /**
         * LOOKUP LINK : arg1 = context name, arg2 = key
         */
        lookupLink,
        /**
         * PING : no arguments
         */
        ping,
        /**
         * REBIND : arg1 = context name, arg2 = key, arg3 = value
         */
        rebind,
        /**
         * RENAME : arg1 = context name, arg2 = old key, arg3 = new key
         */
        rename,
        /**
         * UNBIND : arg1 = context name, arg2 = key
         */
        unbind
    }

    /**
     * First argument
     */
    protected Object arg1;

    /**
     * Second argument
     */
    protected Object arg2;

    /**
     * Third argument
     */
    protected Object arg3;

    /**
     * Type of request
     */
    protected RequestType type;

    protected RegistryRequest(RequestType type, boolean localConnection) {
        super();
        this.type = type;
        this.localConnection = localConnection;
    }

    protected RegistryRequest(RequestType type, Object arg1,
        boolean localConnection) {
        super();
        this.type = type;
        this.arg1 = arg1;
        this.localConnection = localConnection;
    }

    protected RegistryRequest(RequestType type, Object arg1, Object arg2,
        boolean localConnection) {
        super();
        this.type = type;
        this.arg1 = arg1;
        this.arg2 = arg2;
        this.localConnection = localConnection;
    }

    protected RegistryRequest(RequestType type, Object arg1, Object arg2,
        Object arg3, boolean localConnection) {
        super();
        this.type = type;
        this.arg1 = arg1;
        this.arg2 = arg2;
        this.arg3 = arg3;
        this.localConnection = localConnection;
    }

    public Object getArg1() {
        return arg1;
    }

    public Object getArg2() {
        return arg2;
    }

    public Object getArg3() {
        return arg3;
    }

    public RequestType getType() {
        return type;
    }

    public boolean isLocalConnection() {
        return localConnection;
    }

    public void setArg1(Object arg1) {
        this.arg1 = arg1;
    }

    public void setArg2(Object arg2) {
        this.arg2 = arg2;
    }

    public void setArg3(Object arg3) {
        this.arg3 = arg3;
    }

    public void setType(RequestType type) {
        this.type = type;
    }

    public void setLocalConnection(boolean localConnection) {
        this.localConnection = localConnection;
    }

    @Override
    public String toString() {
        return "RegistryRequest : " + type + " - LocalConnection : " + localConnection;
    }

}
