/**
 * Copyright (c) 2005-2012 EBM WebSourcing, 2012-2017 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.microkernel.communication.jndi.client.naming;

import java.net.URI;
import java.net.URISyntaxException;
import java.util.Hashtable;
import java.util.Map;

import javax.naming.Context;
import javax.naming.NamingException;
import javax.naming.spi.InitialContextFactory;

import org.ow2.petals.microkernel.communication.jndi.agent.JNDIAgentService;

/**
 * This class is the InitialContextFactory implementation, it will create the InitialContext.
 * @author ddesjardins - EBM WebSourcing
 */
public class NamingContextFactory implements InitialContextFactory {

    /**
     * @see InitialContextFactory#getInitialContext(Hashtable)
     */
    @SuppressWarnings("unchecked")
    public Context getInitialContext(Hashtable<?, ?> environment) throws NamingException {

        // we do nothing in this method if a local connection is set
        // the InitialContextDecorator will call the others getInitialContext
        // instead
        if (environment.containsKey(JNDIAgentService.ENVIRONMENT_LOCAL_CONNECTION)) {
            return null;
        }
        String jndiString = (String) environment.get(Context.PROVIDER_URL);
        URI jndiUri = null;

        if (jndiString != null) {
            try {
                jndiUri = new URI(jndiString);
            } catch (URISyntaxException e) {
                throw new NamingException("You must specify a proper URI in the property "
                        + Context.PROVIDER_URL);
            }
        } else {
            throw new NamingException("You must specify the property " + Context.PROVIDER_URL);
        }

        NamingConnection jndiConnection = null;
        jndiConnection = new JNDIConnection(jndiUri);

        NamingContextImpl namingContextImpl = new NamingContextImpl(
                (Map<String, Object>) environment, jndiConnection, "/", false);

        return namingContextImpl;
    }

    /**
     * PEtALS dedicated method to get an InitialContext object with a local
     * connection.
     * 
     * @param environment
     * @param jndiAgentService
     * @return
     * @throws NamingException
     */
    @SuppressWarnings("unchecked")
    public Context getInitialContext(Hashtable<?, ?> environment, JNDIAgentService jndiAgentService)
            throws NamingException {

        NamingConnection jndiLocalConnection = new JNDILocalConnection(jndiAgentService);

        NamingContextImpl namingContextImpl = new NamingContextImpl(
                (Map<String, Object>) environment, jndiLocalConnection, "/", true);

        return namingContextImpl;
    }
}
