/**
 * Copyright (c) 2005-2012 EBM WebSourcing, 2012-2017 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.microkernel.communication.jndi.client.naming;

import java.util.Arrays;
import java.util.Iterator;

import javax.naming.NamingEnumeration;
import javax.naming.NamingException;

/**
 * NamingEnumeration implementation.
 * @author ddesjardins - EBM WebSourcing
 */
public class NamingEnumerationImpl<T> implements NamingEnumeration<T> {

    /**
     * Iterator
     */
    protected Iterator<T> iterator;

    /**
     * Creates a new instance of {@link NamingEnumerationImpl}
     *
     * @param array
     */
    public NamingEnumerationImpl(T[] array) {
        super();
        iterator = Arrays.asList(array).iterator();
    }

    /*
     * (non-Javadoc)
     * @see javax.naming.NamingEnumeration#close()
     */
    public void close() throws NamingException {
        iterator = null;
    }

    /*
     * (non-Javadoc)
     * @see javax.naming.NamingEnumeration#hasMore()
     */
    public boolean hasMore() throws NamingException {
        return iterator.hasNext();
    }

    /*
     * (non-Javadoc)
     * @see java.util.Enumeration#hasMoreElements()
     */
    public boolean hasMoreElements() {
        return iterator.hasNext();
    }

    /*
     * (non-Javadoc)
     * @see javax.naming.NamingEnumeration#next()
     */
    public T next() throws NamingException {
        return iterator.next();
    }

    /*
     * (non-Javadoc)
     * @see java.util.Enumeration#nextElement()
     */
    public T nextElement() {
        return iterator.next();
    }

}
