/**
 * Copyright (c) 2013-2017 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.microkernel.extension;

import java.util.ArrayList;
import java.util.List;
import java.util.logging.Logger;

import org.objectweb.fractal.fraclet.annotations.Component;
import org.objectweb.fractal.fraclet.annotations.Interface;
import org.objectweb.fractal.fraclet.annotations.Lifecycle;
import org.objectweb.fractal.fraclet.types.Step;
import org.ow2.petals.microkernel.api.extension.InstallationExtension;

import com.ebmwebsourcing.easycommons.log.LoggingUtil;

/**
 * The implementation of installation extension manager
 * 
 * @author Christophe DENEUX - Linagora
 * 
 */
@Component(provides = @Interface(name = "service", signature = InstallationExtensionsManager.class))
public class InstallationExtensionsManagerImpl implements InstallationExtensionsManager {

    /**
     * The installation extensions deployed.
     */
    private final List<InstallationExtension> extensions = new ArrayList<InstallationExtension>();

    private final LoggingUtil log = new LoggingUtil(
            Logger.getLogger(InstallationExtensionsManager.COMPONENT_LOGGER_NAME));

    /**
     * {@inheritDoc}
     */
    public void register(final InstallationExtension installationExtension) {
        this.log.call();
        this.extensions.add(installationExtension);
    }

    /**
     * {@inheritDoc}
     */
    public void deregister(final InstallationExtension installationExtension) {
        this.log.call();
        this.extensions.remove(installationExtension);
    }

    /**
     * {@inheritDoc}
     */
    public List<InstallationExtension> getExtensions() {
        this.log.call();
        return this.extensions;
    }

    /**
     * Starts the installation extensions manager.
     */
    @Lifecycle(step = Step.START)
    public void start() {
        this.log.call();
    }

    /**
     * Stops the installation extensions manager.
     */
    @Lifecycle(step = Step.STOP)
    public void stop() {
        this.log.call();
    }

}
