/**
 * Copyright (c) 2005-2012 EBM WebSourcing, 2012-2017 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.microkernel.jbi.component.context;

import java.io.File;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

import javax.jbi.component.ComponentContext;
import javax.jbi.component.InstallationContext;

import org.ow2.petals.jbi.descriptor.original.generated.Component;
import org.w3c.dom.Document;
import org.w3c.dom.DocumentFragment;
import org.w3c.dom.Element;

/**
 * @author wjoseph - EBM WebSourcing
 */
public class InstallationContextImpl implements InstallationContext {

    private List<String> classPathElements;

    private String componentClassName;

    private String componentName;

    private ComponentContext context;

    private boolean install;

    private DocumentFragment installationDescriptorExtension;

    private String installRoot;

    public InstallationContextImpl(Component component, ComponentContext context, boolean install) {
        this.context = new ComponentContextForInstallation(context);
        this.componentClassName = component.getComponentClassName().getContent();
        this.componentName = component.getIdentification().getName();
        this.install = install;
        // Set classpath elements with the right file separator
        if (component.getComponentClassPath() != null) {
            List<String> elems = component.getComponentClassPath().getPathElement();
            if (elems != null) {
                List<String> goodSepElems = new ArrayList<>();
                for (String elem : elems) {
                    if (File.separatorChar == '\\') {
                        goodSepElems.add(elem.trim().replace('/', '\\'));
                    } else {
                        goodSepElems.add(elem.trim().replace('\\', '/'));
                    }
                }
                setClassPathElements(goodSepElems);
            }
        }
        this.installRoot = context.getInstallRoot();

        // Build the document fragment from the Any node list
        if (component.getAnyOrAny() != null) {
            DocumentFragment extensions = null;
            // Weird point with the Elements; they have different document owner
            // As workaround, we take the first owner document and adopts all
            // the other Elements with it
            Document initialDocument = null;
            for (Element element : component.getAnyOrAny()) {
                if (extensions == null || initialDocument == null) {
                    initialDocument = element.getOwnerDocument();
                    extensions = initialDocument.createDocumentFragment();
                }
                extensions.appendChild(initialDocument.importNode(element, true));
            }
            this.installationDescriptorExtension = extensions;
        }
    }

    @Override
    public List<String> getClassPathElements() {
        return classPathElements;
    }

    @Override
    public String getComponentClassName() {
        return componentClassName;
    }

    @Override
    public String getComponentName() {
        return componentName;
    }

    @Override
    public ComponentContext getContext() {
        return context;
    }

    @Override
    public DocumentFragment getInstallationDescriptorExtension() {
        return installationDescriptorExtension;
    }

    @Override
    public String getInstallRoot() {
        return installRoot;
    }

    @Override
    public boolean isInstall() {
        return install;
    }

    /*
     * TODO must redefine the classpath at the execution time
     */
    @Override
    public void setClassPathElements(List classPathElements) {
        if (classPathElements == null) {
            throw new IllegalArgumentException("classPathElements cannot be null");
        }
        if (classPathElements.isEmpty()) {
            throw new IllegalArgumentException("classPathElements cannot be empty");
        }

        for (Iterator iter = classPathElements.iterator(); iter.hasNext();) {
            Object obj = iter.next();
            if (!(obj instanceof String)) {
                throw new IllegalArgumentException(
                        "classPathElements must contain element of type String");
            }
            String element = (String) obj;
            String sep = "\\".equals(File.separator) ? "/" : "\\";
            int offset = element.indexOf(sep);
            if (offset > -1) {
                throw new IllegalArgumentException(
                        "classpath ill-formed : classPathElements contains an invalid file separator '"
                                + sep + "'");
            }
            File f = new File(element);
            if (f.isAbsolute()) {
                throw new IllegalArgumentException(
                        "classpath ill-formed : classPathElements should not contain absolute paths");
            }
        }
        this.classPathElements = new ArrayList<>(classPathElements);
    }

    public void setInstall(boolean install) {
        this.install = install;
    }

}
