/**
 * Copyright (c) 2006-2012 EBM WebSourcing, 2012-2017 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.microkernel.jbi.management.recovery.task;

import java.io.File;
import java.net.URISyntaxException;
import java.util.List;

import org.ow2.petals.jbi.descriptor.original.generated.Jbi;
import org.ow2.petals.microkernel.api.container.ContainerService;
import org.ow2.petals.microkernel.api.jbi.management.Context;
import org.ow2.petals.microkernel.api.system.SystemStateService;
import org.ow2.petals.microkernel.api.system.repository.RepositoryService;

import com.ebmwebsourcing.easycommons.log.LoggingUtil;

/**
 * Abstract task for recovering of JBI artifacts needing installation service (components and shared libraries)
 * 
 * @author Olivier Fabre - EBM WebSourcing
 * @author Christophe DENEUX - Linagora
 * 
 */
public abstract class RecoverAbstractInstallationTask extends RecoverAbstractTask {

    public RecoverAbstractInstallationTask(final List<File> unknownDirs, final RepositoryService repositoryService,
            final SystemStateService systemStateService, final ContainerService containerService, final LoggingUtil log) {
        super(unknownDirs, repositoryService, systemStateService, containerService, log);
    }

    /**
     * Create recovery context for component and shared libraries
     * 
     * @param descriptor
     * @param installRoot
     * @return
     * @throws URISyntaxException
     */
    protected Context createRecoveryContext(final Jbi descriptor, final File installFile) {
        final Context installationContext = new Context();
        installationContext.setDescriptor(descriptor);
        installationContext.setInstallFile(installFile);
        installationContext.setUnzipRoot(installFile);
        return installationContext;
    }

}
