/**
 * Copyright (c) 2006-2012 EBM WebSourcing, 2012-2017 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.microkernel.jbi.management.task.deployment.deploy;

import java.io.File;
import java.net.URI;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.ow2.petals.jbi.descriptor.original.generated.Jbi;
import org.ow2.petals.jbi.descriptor.original.generated.ServiceUnit;
import org.ow2.petals.microkernel.api.jbi.management.Context;
import org.ow2.petals.microkernel.api.jbi.management.Task;
import org.ow2.petals.microkernel.api.system.repository.RepositoryService;

import com.ebmwebsourcing.easycommons.log.LoggingUtil;

/**
 * This task renames service unit packages into the repository to fits with service unit ids in the JBI descriptor of
 * the service assembly.
 * <p>
 * Inputs : {@link Jbi}, parent service assembly install root {@link File} <br/>
 * Outputs : SU install roots {@link Map} of {@link File}.
 * </p>
 * 
 * @author Olivier Fabre - EBM WebSourcing
 */
public class RenameSUsTask implements Task {

    /**
     * logger wrapper
     */
    protected LoggingUtil log;

    public RenameSUsTask(RepositoryService repositoryService, LoggingUtil log) {
        super();
        this.log = log;
    }

    @Override
    public void execute(final Context context) throws Exception {
        Jbi descriptor = context.getDescriptor();
        File saInstallFile = context.getInstallFile();

        Map<String, File> suInstallFiles = this.renameSUS(saInstallFile, descriptor);
        context.setSuInstallFiles(suInstallFiles);
    }

    /**
     * Explode service unit packages into the repository
     * 
     * @param saInstallRoot
     *            the root {@link URI} of the service assembly
     * @param descriptor
     *            the service assembly descriptor
     * @return the map containing all SU install roots
     */
    protected Map<String, File> renameSUS(File saInstallFile, Jbi descriptor) {
        Map<String, File> suInstallFiles = new HashMap<String, File>();
        List<ServiceUnit> sus = descriptor.getServiceAssembly().getServiceUnit();
        for (ServiceUnit unit : sus) {
            File suPackageFile = new File(saInstallFile, unit.getTarget().getArtifactsZip());
            File destFile = new File(saInstallFile, unit.getIdentification().getName());
            suPackageFile.renameTo(destFile);
            suInstallFiles.put(unit.getIdentification().getName(), destFile);
        }
        return suInstallFiles;
    }

    @Override
    public void undo(Context context) {
        // Nothing to do
    }

}
