/**
 * Copyright (c) 2007-2012 EBM WebSourcing, 2012-2017 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.microkernel.jbi.management.task.installation.install.sl;

import java.io.File;

import org.ow2.petals.microkernel.api.configuration.ContainerConfiguration;
import org.ow2.petals.microkernel.api.jbi.management.Context;
import org.ow2.petals.microkernel.api.system.SystemStateService;
import org.ow2.petals.microkernel.jbi.management.task.AbstractCreateStateHolderTask;
import org.ow2.petals.systemstate.SystemStateException;

import com.ebmwebsourcing.easycommons.log.LoggingUtil;

/**
 * This task creates state holder for shared library
 * <p>
 * This task MUST be executed with a {@link Context} containing:
 * <ul>
 * <li>shared library name as entity name</li>
 * <li>shared library version as entity version</li>
 * <li>archive {@link File}</li>
 * <li>install {@link File}</li>
 * </ul>
 * and returns no data in the {@link Context}.
 * </p>
 * 
 * @author Olivier Fabre - EBM WebSourcing
 */
public class CreateSLStateHolderTask extends AbstractCreateStateHolderTask {

    public CreateSLStateHolderTask(final LoggingUtil log,
            final SystemStateService systemStateService,
            final ContainerConfiguration containerConfiguration) {
        super(log, systemStateService, containerConfiguration);
    }

    @Override
    protected void createEntityStateHolder(String name, String version, String archiveName)
            throws SystemStateException {
        this.systemStateService.createSharedLibraryStateHolder(name, version, archiveName);
    }

    @Override
    protected void deleteEntityStateHolder(String name, String version) throws Exception {
        this.systemStateService.deleteSharedLibraryStateHolder(name, version);
    }

}
