/**
 * Copyright (c) 2007-2012 EBM WebSourcing, 2012-2017 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.microkernel.jbi.management.task.installation.uninstall.component;

import org.ow2.petals.basisapi.exception.PetalsException;
import org.ow2.petals.microkernel.api.configuration.ContainerConfiguration;
import org.ow2.petals.microkernel.api.container.ContainerService;
import org.ow2.petals.microkernel.api.jbi.management.Context;
import org.ow2.petals.microkernel.jbi.management.task.AbstractLoggableTask;

import com.ebmwebsourcing.easycommons.log.LoggingUtil;

/**
 * This task checks the installation of the component package.
 * 
 * @author Christophe DENEUX - Linagora
 */
public class ComponentCheckInstalledTask extends AbstractLoggableTask {

    private ContainerService containerService;

    public ComponentCheckInstalledTask(final LoggingUtil log, final ContainerService containerService,
            final ContainerConfiguration containerConfiguration) {
        super(log, containerConfiguration);
        this.containerService = containerService;
    }

    public void execute(final Context context) throws Exception {
        final String componentName = context.getEntityName();
        if (this.containerService.getComponentLifecycleByName(componentName) != null) {
            throw new PetalsException("The component '" + componentName + "' is installed.");
        }
    }

    public void undo(Context context) throws Exception {
        // No operation to undo
    }

}
