/**
 * Copyright (c) 2009-2012 EBM WebSourcing, 2012-2017 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.microkernel.jbi.messaging.routing.module;

import java.util.List;
import java.util.logging.Logger;

import org.objectweb.fractal.fraclet.annotations.Component;
import org.objectweb.fractal.fraclet.annotations.Interface;
import org.objectweb.fractal.fraclet.annotations.Lifecycle;
import org.objectweb.fractal.fraclet.annotations.Requires;
import org.objectweb.fractal.fraclet.types.Step;
import org.ow2.petals.jbi.messaging.exchange.PetalsMessageExchange;
import org.ow2.petals.microkernel.api.configuration.ConfigurationService;
import org.ow2.petals.microkernel.api.jbi.messaging.RouterService;
import org.ow2.petals.microkernel.api.jbi.messaging.exception.RoutingException;
import org.ow2.petals.microkernel.transport.Transporter;
import org.ow2.petals.microkernel.transport.util.TransportSendContext;

import com.ebmwebsourcing.easycommons.log.LoggingUtil;

/**
 * @author Roland Naudin - EBM WebSourcing
 */
@Component(provides = @Interface(name = "service", signature = SenderModule.class))
public class TransportResolverModule implements SenderModule {

    /**
     * Logger wrapper.
     */
    protected final LoggingUtil log = new LoggingUtil(
            Logger.getLogger(Constants.FRACTAL_COMPONENT_LOGGER_NAME_TRANSPORT_RESOLVER));

    /**
     * The Topology service fractal component
     */
    @Requires(name = "configuration")
    protected ConfigurationService configurationService;

    private String localContainerName;

    private short attempt;

    private int delay;

    @Override
    public void electEndpoints(final List<TransportSendContext> electedDestinations,
            final PetalsMessageExchange exchange) throws RoutingException {
        this.log.call();

        // TODO handle transport selection by the message Exchange properties or
        // by the topology...

        for (TransportSendContext transportSendContext : electedDestinations) {
            if (this.localContainerName.equals(transportSendContext.getDestination().getContainerName())) {
                transportSendContext.transport = Transporter.LOCAL_FRACTAL_TRANSPORTER;
            } else {
                transportSendContext.transport = Transporter.TCP_FRACTAL_TRANSPORTER;
            }

            if (exchange.getProperty(RouterService.PROPERTY_ROUTER_SEND_ATTEMPT) != null) {
                transportSendContext.attempt = Short
                        .valueOf((String) exchange.getProperty(RouterService.PROPERTY_ROUTER_SEND_ATTEMPT));
            } else {
                transportSendContext.attempt = this.attempt;
            }

            if (exchange.getProperty(RouterService.PROPERTY_ROUTER_SEND_DELAY) != null) {
                transportSendContext.delay = Integer
                        .valueOf((String) exchange.getProperty(RouterService.PROPERTY_ROUTER_SEND_DELAY));
            } else {
                transportSendContext.delay = this.delay;
            }
        }
    }

    /**
     * Start the Fractal component
     */
    @Lifecycle(step = Step.START)
    public void start() {
        this.log.start();

        this.localContainerName = this.configurationService.getContainerConfiguration().getName();
        this.attempt = this.configurationService.getContainerConfiguration().getRouterSendAttempt();
        this.delay = this.configurationService.getContainerConfiguration().getRouterSendDelay();

        this.log.end();
    }

    /**
     * Stop the Fractal component
     */
    @Lifecycle(step = Step.STOP)
    public void stop() {
        this.log.call();
    }

}
