/**
 * Copyright (c) 2008-2012 EBM WebSourcing, 2012-2017 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.microkernel.jbi.security;

import java.io.BufferedReader;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.IOException;
import java.net.URI;
import java.util.ArrayList;
import java.util.List;
import java.util.StringTokenizer;

import javax.xml.namespace.QName;

/**
 * @author Christophe HAMERLING - EBM WebSourcing
 */
public class DefaultAuthorizationParser {

    private static final String SERVICE_KEY = "service";

    private static final String OPERATION_KEY = "operation";

    private static final String ENDPOINT_KEY = "endpoint";

    private static final String ROLES_KEY = "roles";

    private static final String DELIMITER = ";";

    /**
     * The configuration file URL
     */
    private URI uri;

    /**
     * Creates a new instance of DefaultAuthorizationParser
     */
    public DefaultAuthorizationParser(URI uri) {
        this.uri = uri;
    }

    /**
     * 
     * @param file
     * @return
     * @throws IOException
     */
    public DefaultAuthorizationMap parse() throws AuthorizationException {
        List<AuthorizationEntry> entries = new ArrayList<AuthorizationEntry>();

        try (final BufferedReader br = new BufferedReader(new FileReader(new File(uri)))) {
            String line = null;
            while ((line = br.readLine()) != null) {
                // skip lines with beginning with '#'
                if (line.length() > 0 && (line.trim().charAt(0) != '#')) {
                    AuthorizationEntry entry = parseEntry(line);
                    if (entry != null) {
                        entries.add(entry);
                    }
                }
            }
        } catch (FileNotFoundException e) {
            throw new AuthorizationException(e);
        } catch (IOException e) {
            throw new AuthorizationException(e);
        }
        return new DefaultAuthorizationMap(entries);
    }

    /**
     * 
     * @param str
     * @return
     */
    private AuthorizationEntry parseEntry(String str) {
        if (str == null) {
            return null;
        }
        QName service = null;
        QName operation = null;
        String endpoint = null;
        String roles = null;
        str = str.trim();
        StringTokenizer tokenizer = new StringTokenizer(str, DELIMITER);
        while (tokenizer.hasMoreElements()) {
            String token = tokenizer.nextToken();
            if (token.startsWith(ENDPOINT_KEY + "=")) {
                endpoint = token.substring(ENDPOINT_KEY.length() + 1, token.length());
            } else if (token.startsWith(OPERATION_KEY + "=")) {
                operation = QName.valueOf(token.substring(OPERATION_KEY.length() + 1, token
                        .length()));
            } else if (token.startsWith(SERVICE_KEY + "=")) {
                service = QName.valueOf(token.substring(SERVICE_KEY.length() + 1, token.length()));
            } else if (token.startsWith(ROLES_KEY + "=")) {
                roles = token.substring(ROLES_KEY.length() + 1, token.length());
            }
        }
        if (roles == null) {
            roles = "";
        }
        return new AuthorizationEntry(service, endpoint, operation, roles);
    }
}
