/**
 * Copyright (c) 2007-2012 EBM WebSourcing, 2012-2017 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.microkernel.server;

import org.ow2.petals.launcher.api.server.PetalsServer;
import org.ow2.petals.launcher.api.server.exception.PetalsServerException;

import com.ebmwebsourcing.easycommons.log.LoggingUtil;

/**
 * This class launches the stop of the Petals server in a thread.
 * @author Roland Naudin - EBM WebSourcing
 */
public class PetalsStopThread extends Thread {

    private final PetalsServer petalsServer;

    private LoggingUtil logger;

    public PetalsStopThread(final PetalsServer petalsServer, final LoggingUtil log) {
        this.logger = log;
        this.setUncaughtExceptionHandler(new UncaughtExceptionHandler() {
            @Override
            public void uncaughtException(Thread t, Throwable e) {
                PetalsStopThread.this.logger.error(
                        "An unchaught Exception was thrown during the execution of the thread " + t.getName(), e);
            }
        });
        setName("Petals Stop thread");
        this.petalsServer = petalsServer;
    }

    @Override
    public void run() {
        try {
            this.petalsServer.stop();
        } catch (PetalsServerException e) {
            this.logger.error("Error while stopping Petals", e);
        }
    }
}
