/**
 * Copyright (c) 2005-2012 EBM WebSourcing, 2012-2017 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.microkernel.system.classloader;

import java.io.IOException;
import java.net.URL;
import java.util.List;

/**
 * This classloader is used by a component.
 * 
 * It's parent is a shared library classloaders which will take care of delegating to shared libraries for classloading
 * when needed.
 * 
 * @author Olivier Fabre - EBM WebSourcing
 * @author ddesjardins - EBM WebSourcing
 * @author Victor Noël - Linagora
 */
public class ComponentClassLoader extends PetalsClassLoader {

    static {
        // we are parallel capable because parent class is and SharedLibrariesClassLoader is too!
        ClassLoader.registerAsParallelCapable();
    }

    public ComponentClassLoader(final URL[] baseUrls, final List<String> classpathLocations,
            final SharedLibrariesClassLoader parent, final boolean parentFirst)
            throws IOException {
        super(baseUrls, classpathLocations, parent, parentFirst);
    }

    @Override
    public void close() throws IOException {

        // after closing, let's also close the SL classloader since it's tied to us.
        IOException ex = null;
        try {
            super.close();
        } catch (final IOException e) {
            ex = e;
        }

        try {
            ((SharedLibrariesClassLoader) getParent()).close();
        } catch (final IOException e) {
            if (ex != null) {
                e.addSuppressed(ex);
            }
            throw e;
        }

    }

}
