/**
 * Copyright (c) 1999 Bull S.A., 2006-2012 EBM WebSourcing, 2012-2017 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.microkernel.system.classloader.factory;

import java.io.IOException;
import java.net.URL;

/**
 * A <code>DirURLFactory</code> is used to create URLs from an URL (pointing
 * to a directory) and paths. Example : <br/> base : <code>file:/path/</code><br/>
 * path : <code>META-INF/directory/</code><br/> results :
 * <code>file:/path/META-INF/directory/</code><br/>
 * 
 * @author Guillaume Sauthier
 */
public class DirURLFactory extends URLFactory {

    /** the base URL */
    private URL base;

    /**
     * Create a new DirURLFactory using the specified base URL.
     * 
     * @param url
     *            the base url. (must be a directory)
     */
    public DirURLFactory(URL url) {
        base = url;
    }

    /**
     * Returns a new URL basically adding path to the base URL.
     * 
     * @param path
     *            the path to add to the URL. (cannot start with "/")
     * 
     * @return a new URL of the form <base><path>.
     * 
     * @throws IOException
     *             when created URL is invalid.
     */
    @Override
    public URL getURL(String path) throws IOException {
        return new URL(base + path);
    }

}
