/**
 * Copyright (c) 2011-2012 EBM WebSourcing, 2012-2017 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.microkernel.system.logging;

import java.util.ArrayList;
import java.util.List;
import java.util.logging.Logger;

import org.objectweb.fractal.fraclet.annotations.Component;
import org.objectweb.fractal.fraclet.annotations.Interface;
import org.objectweb.fractal.fraclet.annotations.Lifecycle;
import org.objectweb.fractal.fraclet.types.Step;
import org.ow2.petals.commons.log.Level;

import com.ebmwebsourcing.easycommons.log.LoggingUtil;

/**
 * Petals Logging service implementation.
 * @author Sandra Trino - EBM WebSourcing
 */
@Component(provides = @Interface(name = "service", signature = LoggingService.class))
public class LoggingServiceImpl implements LoggingService {

    /**
     * logger wrapper
     */
    private final LoggingUtil log = new LoggingUtil(Logger.getLogger(LoggingServiceImpl.class.getName()));
    
    /**
     * The static list of available log level associated to
     * {@link Level#SUPPORTED_LEVELS}.
     */
    private final static List<String> SUPPORTED_LEVELS_AS_STRING = new ArrayList<String>(
            Level.SUPPORTED_LEVELS.size());

    static {
        for (final java.util.logging.Level level : Level.SUPPORTED_LEVELS) {
            SUPPORTED_LEVELS_AS_STRING.add(level.getName());
        }
    }

    public List<String> getLevels() {
        return SUPPORTED_LEVELS_AS_STRING;
    }
    
    /**
     * Initializes and starts this logging service implementation
     */
    @Lifecycle(step = Step.START)
    public void start() {
        this.log.call();
    }
    
    /**
     * Stops this logging service implementation
     */
    @Lifecycle(step = Step.STOP)
    public void stop() {
        this.log.call();
    }
}
