/**
 * Copyright (c) 2009-2012 EBM WebSourcing, 2012-2017 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.microkernel.system.repository;

import java.io.File;
import java.io.FilenameFilter;
import java.util.Set;
import java.util.regex.Pattern;

/**
 * @author Roland Naudin - EBM WebSourcing
 */
public class RepositoryFileFilter implements FilenameFilter {

    // this is a date followed by sequence of number (the time)
    private final Pattern pattern = Pattern.compile("-[\\d]{2}-[\\d]{2}-[\\d]{4}-[\\d]*");
    private final String entityId;

    private final Set<String> skippedArtifact;

    /**
     * Default constructor.
     * @param entityId
     */
    public RepositoryFileFilter(final String entityId, final Set<String> skippedArtifact) {
        this.entityId = entityId;
        this.skippedArtifact = skippedArtifact;
    }

    @Override
    public boolean accept(final File dir, final String name) {
        // Important: matches() will match on the WHOLE string, not a subset
        return !skippedArtifact.contains(name) && name.startsWith(this.entityId)
                && pattern.matcher(name.substring(this.entityId.length())).matches();
    }

}
