/**
 * Copyright (c) 2015-2017 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.microkernel.transport;

import org.objectweb.fractal.fraclet.annotations.Requires;
import org.ow2.petals.jbi.messaging.exchange.PetalsMessageExchange;

import com.ebmwebsourcing.easycommons.log.LoggingUtil;

/**
 * 
 * @author Victor Noel - Linagora
 *
 */
public abstract class AbstractTransporterImpl implements Transporter {

    /**
     * the Transporter listener (router) Fractal component
     */
    @Requires(name = "transportlistener")
    protected TransportListener transportListener;

    protected final LoggingUtil log;

    protected AbstractTransporterImpl(final LoggingUtil log) {
        this.log = log;
    }

    /**
     * To be called to deliver (by the transport listener) the exchange to the right endpoint
     */
    protected void deliverExchange(final PetalsMessageExchange exchange) throws TransportException {
        this.log.start();

        if (this.log.isDebugEnabled()) {
            this.log.debug(exchange.getExchangeId()
                    + ": we notify the transport listener of this new exchange, it will be dispatched to the right endpoint");
        }

        this.transportListener.onExchange(exchange);

        this.log.end();
    }

    /**
     * To be called to notify the transport listener that the exchange was sent
     */
    protected void notifySent(final PetalsMessageExchange exchange) {
        this.log.start();
        if (this.log.isDebugEnabled()) {
            this.log.debug(exchange.getExchangeId() + ": we notify the transport listener that the exchange was sent");
        }
        this.transportListener.exchangeSent(exchange);
        this.log.end();
    }
}
