/**
 * Copyright (c) 2007-2012 EBM WebSourcing, 2012-2017 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.microkernel.transport.local;

import java.util.logging.Logger;

import org.objectweb.fractal.fraclet.annotations.Component;
import org.objectweb.fractal.fraclet.annotations.Interface;
import org.objectweb.fractal.fraclet.annotations.Requires;
import org.ow2.petals.jbi.messaging.exchange.PetalsMessageExchange;
import org.ow2.petals.microkernel.transport.AbstractTransporterImpl;
import org.ow2.petals.microkernel.transport.TransportException;
import org.ow2.petals.microkernel.transport.Transporter;
import org.ow2.petals.microkernel.transport.local.monitoring.LocalTransporterMonitoring;
import org.ow2.petals.microkernel.transport.util.TransportSendContext;
import org.ow2.petals.probes.api.enums.ExecutionStatus;
import org.ow2.petals.probes.api.key.ProbeKey;

import com.ebmwebsourcing.easycommons.log.LoggingUtil;

/**
 * @author Roland NAUDIN - EBM WebSourcing
 * @author Victor Noel - Linagora
 */
@Component(provides = { @Interface(name = "service", signature = Transporter.class) })
public class LocalTransporterImpl extends AbstractTransporterImpl {

    /**
     * The local transporter monitoring service - Fractal component
     */
    @Requires(name = "localtransportermonitoring")
    protected LocalTransporterMonitoring localTransporterMonitoring;

    public LocalTransporterImpl() {
        super(new LoggingUtil(Logger.getLogger(Constants.FRACTAL_COMPONENT_LOGGER_NAME)));
    }

    @Override
    protected void notifySent(final PetalsMessageExchange exchange) {
        this.log.start();

        if (this.log.isDebugEnabled()) {
            this.log.debug(exchange.getExchangeId()
                    + ": we notify the local transport monitor that the exchange was sent");
        }

        super.notifySent(exchange);

        this.log.end();
    }

    @Override
    public void send(final PetalsMessageExchange exchange, final TransportSendContext transportContext)
            throws TransportException {
        this.log.start();

        if (this.log.isDebugEnabled()) {
            this.log.debug("Sending exchange " + exchange.getExchangeId());
        }

        final ProbeKey probeKey = this.localTransporterMonitoring.incPendingMessageProbe();
        try {
            // in that case, let's give the exchange to the one that should get it
            this.deliverExchange(exchange);

            this.localTransporterMonitoring.endsPendingMessagesProbe(probeKey, ExecutionStatus.SUCCEEDED);

            // now we can consider the message has been sent
            this.notifySent(exchange);
        } catch (final TransportException e) {
            this.localTransporterMonitoring.endsPendingMessagesProbe(probeKey, ExecutionStatus.ERROR);
            throw e;
        }

        this.log.end();
    }
}
