/**
 * Copyright (c) 2009-2012 Capgemini, 2009-2012 EBM WebSourcing, 2012-2017 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.microkernel.transport.platform.nio.selector;

import java.nio.ByteBuffer;
import java.nio.channels.SocketChannel;

/**
 * The socket channel context of an input socket. It contains following information:
 * <ul>
 * <li>the socket channel.</li>
 * </ul>
 * 
 * @author Christophe DENEUX - Capgemini Sud
 */
public class AbstractSocketChannelContext {
    
    protected final static int INTEGER_SIZE_BYTE = Integer.SIZE / 8;

    /**
     * NIO Direct buffer containing available bytes of the pending IO.
     */
    protected ByteBuffer directBuffer;

    /**
     * State of the pending IO:
     * <ul>
     * <li><code>true</code>: the buffer contains bytes of a pending IO,</li>
     * <li><code>false</code>: no byte are reading or writing.</li>
     * </ul>
     * It is set to <code>true</code> after to have read or written the
     * externalized message exchange header (its size). It is set to
     * <code>false</code> after to have read or written the externalized message
     * completely, and to have transmitted the data to an externalized message
     * exchange worker in case of read (to do deserialization and so on).
     */
    protected boolean isIOPending;

    /**
     * <p>
     * Remaining bytes to read/write of the externalized message exchange. It
     * should be initialized with the size of the externalized message exchange
     * size plus the header size.
     * </p>
     * <p>
     * Note: "Remaining bytes to write" must understand as
     * "Remaining bytes to put in the NIO direct buffer" and not as
     * "Remaining byts to write in the TCP socket"
     * </p>
     */
    protected int msgExRemainingBytes;

    /**
     * The socket channel
     */
    protected final SocketChannel socketChannel;

    /**
	 * Create a socket channel context.
	 * 
	 * @param socketChannel
	 * @param byteBufferCapacity
	 *            Size of the direct buffer to use to read or write bytes.
	 */
    public AbstractSocketChannelContext(final SocketChannel socketChannel, final int byteBufferCapacity) {
        this.socketChannel = socketChannel;
        this.directBuffer = ByteBuffer.allocateDirect(byteBufferCapacity);
        this.isIOPending = false;
        }

}
