/**
 * Copyright (c) 2009-2012 Capgemini, 2009-2012 EBM WebSourcing, 2012-2017 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.microkernel.transport.platform.nio.selector;

import java.io.IOException;
import java.nio.channels.Selector;
import java.nio.channels.SocketChannel;

/**
 * Interface of the Fractal component associated to the NIO server.
 * @author Christophe DENEUX - Capgemini Sud
 */
public interface NioServer {
    
    public final static String NIO_SERVER_ITF = "server";

    /**
     * Notify the {@link NioServer} implementation that the given connection was closed.
     */
    void onClose(final SocketChannel socketChannel);
    
    /**
     * Notify the {@link NioServer} implementation that the given connection was accepted.
     */
    void onConnectionIsAccepted(final SocketChannel socketChannel,
			final Selector selector) throws IOException ;

    /**
     * Notify the {@link NioServer} implementation that reads occurs on the given connection.
     */
    void onRead(final PipedDeserializer deserializer);

    /**
     * Notify the {@link NioServer} implementation that the given connection becomes ACTIVE, and data associated to a
     * message exchange start to be read.
     */
    public void onConnectionActive(final SocketChannel socketChannel);

    /**
     * Notify the {@link NioServer} implementation that the given connection becomes IDLE, and data associated to a
     * message exchange was read.
     */
    public void onConnectionIdle(final SocketChannel socketChannel);

    /**
     * @param containerIpAddress
     *            The IP address of the container
     * @return the number of connections currently in state ACTIVE for the given container.
     */
    public long getNumActiveConnections(final String containerIpAddress);

    /**
     * @param containerIpAddress
     *            The IP address of the container
     * @return the number of connections currently in state IDLE for the given container.
     */
    public long getNumIdleConnections(final String containerIpAddress);
}
