/**
 * Copyright (c) 2005-2012 EBM WebSourcing, 2012-2017 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.microkernel.util;

import java.util.Properties;

import javax.naming.CompoundName;
import javax.naming.InvalidNameException;
import javax.naming.Name;
import javax.xml.namespace.QName;

/**
 * Class managing mapping between String and QName.
 * @author Adrien LOUIS - EBM WebSourcing
 */
public final class NamingHelper {

    private NamingHelper() {
        // avoid to be build
    }

    /**
     * 
     * @param n
     * @return
     */
    public static String nameToString(Name n) {
        return n != null ? n.toString() : null;
    }

    /**
     * ns - localpart replaced with "{ns}localpart"
     * 
     * @param qn
     * @return null if qn is null
     */
    public static String qNameToString(QName qn) {
        if (qn != null) {
            if (!"".equals(qn.getNamespaceURI())) {
                return "{" + qn.getNamespaceURI() + "}" + qn.getLocalPart();
            } else {
                return qn.getLocalPart();
            }
        } else {
            return null;
        }
    }

    /**
     * 
     * @param s
     * @return
     */
    public static Name stringToName(String s) {
        CompoundName compoundName;
        try {
            compoundName = new CompoundName(s, new Properties());
        } catch (InvalidNameException e) {
            compoundName = null;
        }
        return compoundName;
    }

    /**
     * "{ns}localpart" replaced by ns - localpart
     * 
     * @param s
     * @return
     */
    public static QName stringToQName(String s) {
        return QName.valueOf(s);
    }

}
