/**
 * Copyright (c) 2014-2017 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.microkernel.communication.topology;

import org.junit.Test;
import org.ow2.petals.clientserverapi.topology.exception.DomainIsNotDynamicException;
import org.ow2.petals.microkernel.api.configuration.ContainerConfiguration;
import org.ow2.petals.microkernel.api.configuration.DomainConfiguration.DomainMode;

/**
 * Unit tests of {@link TopologyServiceImpl#attachContainerTo(ContainerConfiguration, String)}
 * 
 * @author Christophe DENEUX - Linagora
 * 
 */
public class TopologyServiceImpl_DetachContainerTest extends AbstractTopologyServiceImplTest {

    /**
     * <p>
     * Check {@link TopologyServiceImpl#detachContainerTo()} against:
     * <ul>
     * <li>the domain of the current container is static</li>
     * </ul>
     * </p>
     * <p>
     * Expected results: An error occurs because the domain mode is not <b>dynamic</b>
     * </p>
     */
    @Test(expected = DomainIsNotDynamicException.class)
    public void testCurrentDomainNotDynamic() throws Exception {
        try (final TestConfigurationService cfgSvc = createAndStartConfSvc();
                final TestTopologyService topoSvc = createAndStartTopologySvc(cfgSvc, null)) {
            assertEquals(DomainMode.STATIC, cfgSvc.getDomainConfiguration().getMode());
            topoSvc.detachContainer();
        }
    }

}
