/**
 * Copyright (c) 2011-2012 EBM WebSourcing, 2012-2017 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.microkernel.jbi.management.task.installation.install.sl;

import java.io.FileNotFoundException;
import java.util.logging.Logger;

import org.easymock.EasyMock;
import org.junit.Test;
import org.ow2.petals.microkernel.api.jbi.management.Context;
import org.ow2.petals.microkernel.api.jbi.management.Task;
import org.ow2.petals.microkernel.api.system.repository.RepositoryService;
import org.ow2.petals.microkernel.jbi.management.task.installation.uninstall.sl.RemoveSLRepositoryTask;
import org.ow2.petals.microkernel.util.AbstractMavenTest;

import com.ebmwebsourcing.easycommons.log.LoggingUtil;

/**
 * Test class for the task {@link RemoveSLRepositoryTask}.
 * @author Christophe DENEUX - EBM WebSourcing
 */
public class RemoveSLRepositoryTaskTest extends AbstractMavenTest {

    final static private String SL_NAME = "mySLName";

    final static private String SL_VERSION = "1.0.0";

    final LoggingUtil log = new LoggingUtil(Logger.getLogger(
            RemoveSLRepositoryTaskTest.class.getName()));

    /**
     * Check interaction between the tested task and the repository service,
     * when processing the task.
     * 
     * @throws Exception
     */
    @Test    
    public void testRemoveSLRepositoryTask_000() throws Exception {
        final RepositoryService repositorySvc = EasyMock.createMock(RepositoryService.class);
        repositorySvc.removeSharedLibrary(SL_NAME, SL_VERSION);
        EasyMock.replay(repositorySvc);

        final Context ctx = new Context();
        ctx.setEntityName(SL_NAME);
        ctx.setEntityVersion(SL_VERSION);
        final Task task = new RemoveSLRepositoryTask(log, repositorySvc, null);

        // Process the task.
        task.execute(ctx);

        // Verify interaction between the current test and the repository.
        EasyMock.verify(repositorySvc);
    }

    /**
     * Check interaction between the tested task and the repository service,
     * when processing the task twice for the same shared library.
     * 
     * @throws Exception
     */
    @Test    
    public void testRemoveSLRepositoryTask_001() throws Exception {
        final RepositoryService repositorySvc = EasyMock.createMock(RepositoryService.class);
        repositorySvc.removeSharedLibrary(SL_NAME, SL_VERSION);
        repositorySvc.removeSharedLibrary(SL_NAME, SL_VERSION);
        EasyMock.expectLastCall().andThrow(new FileNotFoundException());
        EasyMock.replay(repositorySvc);

        // First, process the task for the 1st installation of the shared
        // library
        {
            final Context ctx1 = new Context();
            ctx1.setEntityName(SL_NAME);
            ctx1.setEntityVersion(SL_VERSION);
            final Task task1 = new RemoveSLRepositoryTask(log, repositorySvc, null);
            task1.execute(ctx1);
        }

        // Second, process the task for the 2nd installation of the shared
        // library
        {
            final Context ctx2 = new Context();
            ctx2.setEntityName(SL_NAME);
            ctx2.setEntityVersion(SL_VERSION);
            final Task task2 = new RemoveSLRepositoryTask(log, repositorySvc, null);
            task2.execute(ctx2);
            // No exception is raised if an error occurs during task execution.
        }

        // Verify interaction between the current test and the repository
        // service.
        EasyMock.verify(repositorySvc);
    }

}
