/**
 * Copyright (c) 2014-2017 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.microkernel.utest.mock.jbi.management;

import java.util.Collection;
import java.util.HashMap;
import java.util.Map;

import javax.management.ObjectName;

import org.objectweb.fractal.api.Component;
import org.objectweb.fractal.fraclet.annotations.Interface;
import org.objectweb.fractal.fraclet.annotations.Lifecycle;
import org.objectweb.fractal.fraclet.types.Step;
import org.ow2.petals.basisapi.exception.PetalsException;
import org.ow2.petals.jbi.descriptor.original.generated.ComponentType;
import org.ow2.petals.jbi.descriptor.original.generated.Jbi.SharedLibrary;
import org.ow2.petals.microkernel.api.container.ComponentLifeCycle;
import org.ow2.petals.microkernel.api.container.ContainerService;
import org.ow2.petals.microkernel.api.container.Installer;
import org.ow2.petals.microkernel.api.container.ServiceAssemblyLifeCycle;
import org.ow2.petals.microkernel.api.container.ServiceUnitLifeCycle;
import org.ow2.petals.microkernel.api.container.SharedLibraryBean;
import org.ow2.petals.microkernel.api.container.SharedLibraryLifeCycle;
import org.ow2.petals.microkernel.api.container.exception.ComponentLifecycleNotFoundException;
import org.ow2.petals.microkernel.api.container.exception.ContainerServiceException;
import org.ow2.petals.microkernel.api.container.exception.InstallerNotFoundException;
import org.ow2.petals.microkernel.container.ContainerController;

/**
 * A implementation of {@link ContainerController} for unit tests
 * 
 * @author Christophe DENEUX - Linagora
 */
@org.objectweb.fractal.fraclet.annotations.Component(provides = @Interface(name = "service", signature = ContainerService.class))
public class ContainerServiceImpl implements ContainerService {

    private final Map<String, org.ow2.petals.jbi.descriptor.original.generated.Component> installers = new HashMap<String, org.ow2.petals.jbi.descriptor.original.generated.Component>();

    @Override
    public Component getParentContainer() {
        return null;
    }

    @Override
    public Installer createInstaller(
            final org.ow2.petals.jbi.descriptor.original.generated.Component componentDescription)
            throws ContainerServiceException {

        this.installers.put(componentDescription.getIdentification().getName(), componentDescription);

        return null;
    }

    @Override
    public ObjectName registerInstallerMBean(final String name) throws InstallerNotFoundException,
            ContainerServiceException {

        return null;
    }

    @Override
    public void unregisterInstallerMBean(final String name) throws InstallerNotFoundException,
            ContainerServiceException {

        // NOP
    }

    public ComponentLifeCycle createComponentLifeCycle(
            final org.ow2.petals.jbi.descriptor.original.generated.Component componentDescription)
            throws ContainerServiceException {

        return null;
    }

    @Override
    public ObjectName registerComponentLifeCycleMBean(final String name) throws ComponentLifecycleNotFoundException,
            ContainerServiceException {

        return null;
    }

    @Override
    public void unregisterComponentLifeCycleMBean(final String name) throws ComponentLifecycleNotFoundException,
            ContainerServiceException {

        // NOP
    }

    @Override
    public void removeComponentLifeCycle(final String name) throws PetalsException {

        // NOP
    }

    @Override
    public void removeInstaller(final String name) throws PetalsException {

        // NOP
    }

    @Override
    public ServiceAssemblyLifeCycle createServiceAssemblyLifeCycle(
            final org.ow2.petals.jbi.descriptor.original.generated.ServiceAssembly sa) throws ContainerServiceException {

        return null;
    }

    @Override
    public void removeServiceAssemblyLifeCycle(final String saName) throws PetalsException {

        // NOP
    }

    @Override
    public SharedLibraryLifeCycle createSharedLibraryLifeCycle(final SharedLibrary sl) throws ContainerServiceException {

        return null;
    }

    @Override
    public void removeSharedLibraryLifeCycle(final String slName, final String slVersion) throws PetalsException {

        // NOP
    }

    /**
     * Initialization of the Fractal component.
     */
    @Lifecycle(step = Step.START)
    public void start() {
        // NOP
    }

    /**
     * Stop of the Fractal component.
     * 
     */
    @Lifecycle(step = Step.STOP)
    public void stop() {
        // NOP
    }

    @Override
    public Installer getInstallerByName(final String name) {
        return null;
    }

    @Override
    public Map<String, Installer> getInstallers() {
        return null;
    }

    @Override
    public Map<String, ComponentLifeCycle> getComponentLifecycles() {
        return null;
    }

    @Override
    public ComponentLifeCycle getComponentLifecycleByName(final String name) {
        return null;
    }

    @Override
    public boolean isBindingComponent(final String componentName) {
        return this.checkComponentType(componentName, ComponentType.BINDING_COMPONENT);
    }

    @Override
    public boolean isServiceEngine(final String componentName) {
        return this.checkComponentType(componentName, ComponentType.SERVICE_ENGINE);
    }

    /**
     * Check that a JBI component is a component of the given type.
     * 
     * @param componentName
     *            The JBI component identifier
     * @param expectedType
     *            The expected type of the component
     * @return <code>true</code> if the JBI component has the give type, <code>false</code> otherwise.
     */
    private boolean checkComponentType(final String componentName, final ComponentType expectedType) {

        if (this.installers.containsKey(componentName)) {
            return this.installers.get(componentName).getType() == expectedType;
        } else {
            return false;
        }
    }

    @Override
    public ServiceAssemblyLifeCycle getServiceAssemblyByName(final String saName) {
        return null;
    }

    @Override
    public Map<String, ServiceAssemblyLifeCycle> getServiceAssemblies() {
        return null;
    }

    @Override
    public SharedLibraryLifeCycle getSharedLibraryByName(final String slName, final String slVersion) {
        return null;
    }

    @Override
    public Map<SharedLibraryBean, SharedLibraryLifeCycle> getSharedLibraries() {
        return null;
    }

    @Override
    public Collection<String> getServiceEnginesNames() {
        return null;
    }

    @Override
    public Collection<String> getBindingComponentsNames() {
        return null;
    }

    @Override
    public Collection<ServiceUnitLifeCycle> getServiceUnitsLifeCyclesByComponent(String component) {
        return null;
    }

}
